## Overview

**What is Apache Hadoop?**

The Apache Hadoop software library is a framework that allows for the
distributed processing of large data sets across clusters of computers
using a simple programming model.

It is designed to scale up from single servers to thousands of machines,
each offering local computation and storage. Rather than rely on hardware
to deliver high-avaiability, the library itself is designed to detect
and handle failures at the application layer, so delivering a
highly-availabile service on top of a cluster of computers, each of
which may be prone to failures.

Apache Hadoop 2.4.1 consists of significant improvements over the previous stable
release (hadoop-1.x).

Here is a short overview of the improvments to both HDFS and MapReduce.

 - **HDFS Federation**
   In order to scale the name service horizontally, federation uses multiple
   independent Namenodes/Namespaces. The Namenodes are federated, that is, the
   Namenodes are independent   and don't require coordination with each other.
   The datanodes are used as common storage for blocks by all the Namenodes.
   Each datanode registers with all the Namenodes in the cluster.   Datanodes
   send periodic heartbeats and block reports and handles commands from the
   Namenodes.

   More details are available in the HDFS Federation document:
   <http://hadoop.apache.org/docs/r2.4.1/hadoop-project-dist/hadoop-hdfs/Federation.html>

 - **MapReduce NextGen aka YARN aka MRv2**
   The new architecture introduced in hadoop-0.23, divides the two major functions of the
   JobTracker: resource management and job life-cycle management into separate components.
   The new ResourceManager manages the global assignment of compute resources to
   applications and the per-application ApplicationMaster manages the application‚
   scheduling and coordination.
   An application is either a single job in the sense of classic MapReduce jobs or a DAG of
   such jobs.

   The ResourceManager and per-machine NodeManager daemon, which manages the user
   processes on   that machine, form the computation fabric.

   The per-application ApplicationMaster is, in effect, a framework specific
   library and is tasked with negotiating resources from the ResourceManager and
   working with the NodeManager(s) to execute and monitor the tasks.

   More details are available in the YARN document:
   <http://hadoop.apache.org/docs/r2.4.1/hadoop-yarn/hadoop-yarn-site/YARN.html>

## Usage

This charm manages the hadoop client node.  It is intended to be used with
`apache-hadoop-hdfs-master` and `apache-hadoop-yarn-master`.

### Simple Usage: Single-node deployment

In this configuration, all components run on the same machine.  This
is useful for experimenting with Apache Hadoop::

    juju deploy apache-hadoop-hdfs-master hdfs
    juju deploy apache-hadoop-yarn-master yarn --to hdfs
    juju deploy apache-hadoop-client client --to hdfs
    juju add-relation hdfs client
    juju add-relation yarn client


### Scale Out Usage: Separate HDFS, YARN, and compute nodes

In this configuration the HDFS and YARN deployments operate on
different service units as separate services::

    juju deploy apache-hadoop-hdfs-master hdfs-master
    juju deploy apache-hadoop-yarn-master yarn-master
    juju deploy apache-hadoop-compute-slave compute-slaves
    juju add-unit -n 3 compute-slaves
    juju add-relation hdfs-master compute-slaves
    juju add-relation yarn-master compute-slaves


### TO deploy a Hadoop service with elasticsearch service::
    # deploy ElasticSearch locally:
    **juju deploy elasticsearch elasticsearch**
    # elasticsearch-hadoop.jar file will be added to LIBJARS path
    # Recommanded to use hadoop -libjars option to included elk jar file
    **juju add-unit -n elasticsearch**
    # deploy hive service by any senarios mentioned above
    # associate Hive with elasticsearch
    **juju add-relation {hadoop master}:elasticsearch elasticsearch:client**

## Contact Information
amir sanjar <amir.sanjar@canonical.com>

## Hadoop
- [Apache Hadoop](http://hadoop.apache.org/) home page
- [Apache Hadoop bug trackers](http://hadoop.apache.org/issue_tracking.html)
- [Apache Hadoop mailing lists](http://hadoop.apache.org/mailing_lists.html)
- [Apache Hadoop Juju Charm](http://jujucharms.com/?text=hadoop)
