#!/usr/bin/env python

from subprocess import check_call
from jujuresources import verify_resources
from jujuresources import resource_path


def bootstrap_resources():
    check_call(['pip', 'install', resource_path('pathlib')])
    #check_call(['pip', 'install', resource_path('charmhelpers')])


def manage():
    if not verify_resources():
        # defer until resources are available, since charmhelpers, and thus
        # the framework, (will be) managed by jujuresources
        return
    bootstrap_resources()

    from charmhelpers.core import charmdata
    from charmhelpers.core import ch_framework
    from charmhelpers.contrib import bigdata

    hadoop = bigdata.handlers.apache.HadoopBase()
    hdfs = bigdata.handlers.apache.HDFS(hadoop)
    yarn = bigdata.handlers.apache.YARN(hadoop)
    manager = ch_framework.Manager([
        {
            'name': 'hadoop-base',
            'requires': [
                lambda: not charmdata.kv.get('hadoop.base.installed'),
                hadoop.verify_conditional_resources,
            ],
            'callbacks': [
                hadoop.install,
                lambda: charmdata.kv.set('hadoop.base.installed', True),
            ],
        },
        {
            'name': 'client',
            'provides': [],
            'requires': [
                lambda: charmdata.kv.get('hadoop.base.installed'),
                bigdata.relations.HDFSMasterRelation(spec=hadoop.spec),
                bigdata.relations.YARNMasterRelation(spec=hadoop.spec),
            ],
            'callbacks': [
                hdfs.configure_client,
                yarn.configure_client,
            ],
            'cleanup': [
            ],
        },
    ])
    manager.manage()


if __name__ == '__main__':
    manage()
